==> rutorrent-3.9.tar.gz: ruTorrent-3.9/lang/zh-tw.js <==
﻿/*
 * Chinese Traditional language file.
 *
 * Author: Eyes Blue (kingofeyesblue@yahoo.com.tw)
 */

var theUILang =
{
 General			: "一般",
 Downloads			: "下載",
 Connection			: "連線",
 BitTorrent			: "任務",
 Advanced			: "進階",
 User_Interface 		: "使用者界面",
 Confirm_del_torr		: "刪除 Torrent 時要求確認",
 Update_GUI_every		: "更新圖形介面頻率",
 ms				: "ms",
 Alt_list_bckgnd		: "交替顯示列表背景色",
 Show_cat_start 		: "啟動時顯示類別",
 Show_det_start 		: "啟動時顯示詳細內容",
 Dnt_start_down_auto		: "不要自動開始下載",
 Listening_Port 		: "連接埠設定",
 Port_f_incom_conns		: "本機連接埠",
 Rnd_port_torr_start		: "rTorrent 啟動時使用隨機連接埠",
 Type				: "類型",
 Bandwidth_Limiting 		: "頻寬限制",
 Global_max_upl 		: "整體最大上傳速度",
 unlimited			: "無限制",
 Glob_max_downl 		: "整體最大下載速度",
 Add_bittor_featrs		: "其他功能選項",
 En_DHT_ntw			: "啟用 DHT 網絡",
 Peer_exch			: "啟用使用者資訊交換",
 Ip_report_track		: "提供給 Tracker 的本機 IP 地址/主機名稱",
 Disabled			: "禁用",
 Enabled			: "啟用",
 ruTorrent_settings		: "設定",
 Doesnt_support 		: "這個 ruTorrent 不支援您使用的瀏覽器",
 Name				: "名稱",
 Status 			: "狀態",
 Size				: "大小",
 Done				: "完成率",
 Downloaded			: "已下載",
 Uploaded			: "已上傳",
 Ratio				: "分享率",
 DL				: "下載速度",
 UL				: "上傳速度",
 ETA				: "剩餘時間",
 Label				: "標籤",
 Peers				: "用戶數量",
 Seeds				: "種子數量",
 Remaining			: "剩餘時間",
 Priority			: "優先等級",
 Not_torrent_file		: "該檔案不是有效的 torrent 檔案",
 Pausing			: "暫停中",
 Seeding			: "做種中",
 Downloading			: "下載中",
 Checking			: "檢查中",
 Error				: "錯誤",
 Queued 			: "排隊中",
 Finished			: "已完成",
 Stopped			: "已停止",
 Request_timed_out		: "連接 rTorrent 逾時",
 Start				: "開始",
 Pause				: "暫停",
 Stop				: "停止",
 Force_recheck			: "強制重新檢查",
 New_label			: "新建標籤...",
 Remove_label			: "移除標籤",
 Labels 			: "標籤",
 Remove 			: "移除",
 Delete_data			: "刪除下載的資料",
 Remove_and			: "移除並",
 Details			: "詳細內容...",
 Properties			: "屬性...",
 of				: "的", //this two creates line
 connected			: "已連接", //  XX of YY connected
 High_priority			: "較高優先權",
 Normal_priority		: "正常優先權",
 Low_priority			: "較低優先權",
 Dont_download			: "不要下載",
 Files				: "文件",
 Logger 			: "紀錄",
 s				: "s", // part of "KB/s"
 bytes				: "bytes",
 KB				: "KiB",
 MB				: "MiB",
 GB				: "GiB",
 TB				: "TiB",
 PB				: "PiB",
 Loading			: "載入中...",
 Torrent_file			: "Torrent 檔案",
 Torrent_URL			: "Torrent 網址",
 Torrent_properties		: "Torrent 屬性",
 Trackers			: "Tracker",
 Bandwidth_sett 		: "頻寬設定",
 Number_ul_slots		: "上傳通道數",
 Peer_ex			: "用戶資料交換",
 Enter_label_prom		: "為選擇的 Torrent 輸入新的標籤",
 Remove_torrents		: "移除 Torrent(s)",
 Rem_torrents_prompt		: "您確定要移除選擇的 Torrent 嗎?",
 All				: "全部",
 Active 			: "活動",
 Inactive			: "停止",
 No_label			: "其他",
 Transfer			: "傳輸",
 Time_el			: "已用時間",
 Share_ratio			: "分享比率",
 Down_speed			: "下載速度",
 Ul_speed			: "上傳速度",
 Wasted 			: "丟棄數據",
 Tracker			: "Tracker",
 Track_URL			: "Tracker 連接",
 Track_status			: "Tracker 狀態",
 Save_as			: "檔案儲存位置",
 Created_on			: "建立時間",
 Comment			: "附註說明",
 add_button			: "開啟",
 add_url			: "下載",
 ok				: "確定",
 Cancel 			: "取消",
 mnu_add			: "開啟 Torrent",
 mnu_remove			: "移除",
 mnu_start			: "開始",
 mnu_pause			: "暫停",
 mnu_stop			: "停止",
 mnu_rss			: "RSS 下載器",
 mnu_settings			: "設定",
 mnu_search			: "搜尋",
 mnu_lang			: "語言",
 torrent_add			: "開啟 Torrent", /*Caption of torrent add box*/
 time_w 			: "週 ", /*for x weeks*/
 time_d 			: "日 ", /*for x days remaining*/
 time_h 			: "時 ", /*for x hours remaining*/
 time_m 			: "分 ", /*for x minutes remaining*/
 time_s 			: "秒 ", /*for x seconds remaining*/
 Base_directory 		: "存放目錄",
 Number_Peers_min		: "與其他使用者連線的最小數量",
 Number_Peers_max		: "與其他使用者連線的最大數量",
 Tracker_Numwant		: "向tracker查詢使用者資訊時，期望一次回應的數量",
 Number_Peers_For_Seeds_min	: "作種時與其他使用者連線的最小數量",
 Number_Peers_For_Seeds_max	: "作種時與其他使用者連線的最大數量",
 Enable_port_open		: "監聽連接埠",
 dht_port			: "DHT 使用的 UDP 連接埠",
 Other_Limiting 		: "其他限制",
 Number_dl_slots		: "最大下載連線數量",
 Glob_max_memory		: "整體最大記憶體可用量",
 Glob_max_files 		: "整體最大可開啟的檔案數量",
 Glob_max_http			: "整體最大 HTTP 連線數量",
 Other_sett			: "其他設定",
 Directory_For_Dl		: "預設下載目錄",
 Check_hash			: "下載完成後使用 Hash 完整驗證所有檔案",
 Hash				: "Hash",
 DisableTracker 		: "停用",
 EnableTracker			: "啟用",
 ClientVersion			: "Client",
 Flags				: "Flags",
 ReqTimeout			: "判定逾時",
 GetTrackerMessage		: "從tracker接收使用者資訊",
 Help				: "Help",
 Speed				: "速度",
 Dont_add_tname 		: "請勿將 torrent 名稱作為目錄名稱",
 Free_Disk_Space		: "磁碟可用空間",
 badXMLRPCVersion		: "rTorrent使用了錯誤的xmlrpc-c版本編譯, 該版本不含i8支援,版本必須大於或等於1.11版,某些功能將無法使用",
 badLinkTorTorrent		: "錯誤的rTorrent連結, 請檢查rTorrent是否已經正確執行, 請確認rTorrent設定檔與config.php中的 $scgi_port 與 $scgi_host 相符合",
 badUploadsPath 		: "網頁伺服器無法存取(讀/寫/執行) torrent 的存放目錄，您無法從 ruTorrent 新增 torrent",
 badSettingsPath		: "網頁伺服器無法存取(讀/寫/執行)設定檔存放目錄，ruTorrent 無法儲存設定",
 mnu_help			: "關於",
 badUploadsPath2		: "rTorrent's 所設定的使用者無法讀/執行 torrent 的存放目錄，您無法從 ruTorrent 新增 torrent",
 View				: "檢視",
 AsList 			: "列表檢視",
 AsTree 			: "樹狀檢視",
 Group				: "群組",
 SuperSeed			: "超級種子",
 badTestPath			: "rTorrent's 所設定的使用者無權限讀/執行./test.sh，ruTorrent 無法正常運作",
 badSettingsPath2		: "rTorrent's 無法存取(讀/寫/執行)您所設定的使用者家目錄，ruTorrent 無法正常運作",
 scrapeDownloaded		: "已下載",
 Total				: "總計",
 PCRENotFound			: "PHP 中未安裝 PCRE 模組，ruTorrent 無法正常運>作",
 addTorrentSuccess		: "torrent 檔案上傳完成",
 addTorrentFailed		: "錯誤: torrent 檔案無法傳送到 rTorrent",
 pnlState			: "狀態",
 newLabel			: "新標籤",
 enterLabel			: "Enter Label",
 UIEffects			: "Show effects for UI elements",
 Plugins			: "Plugins",
 plgName			: "Name",
 plgStatus			: "Status",
 plgLoaded			: "Loaded",
 plgDisabled			: "Not loaded",
 plgVersion			: "Version",
 plgAuthor			: "Author",
 plgDescr			: "Description",
 mnu_go 			: "Go",
 pluginCantStart		: "Plugin failed to start.",
 doFastResume			: "Fast resume",
 innerSearch			: "Local Torrents",
 removeTeg			: "Remove tag",
 errMustBeInSomeHost		: "ruTorrent and rTorrent must be installed on the same host. Plugin will not work.",
 warnMustBeInSomeHost		: "ruTorrent and rTorrent must be installed on the same host. Some functionality will be unavailable.",
 plgShutdown			: "Unload",
 limit				: "Limit",
 speedList			: "Speed Popup List (comma-separated)",
 ClearButton			: "Clear",
 dontShowTimeouts		: "Ignore message about timeouts",
 fullTableRender		: "Full render of large tables",
 showScrollTables		: "Show table contents while scrolling",
 idNotFound			: "rTorrent user can't access 'id' program. Some functionality will be unavailable.",
 gzipNotFound			: "Webserver user can't access 'gzip' program. ruTorrent will not work.",
 cantObtainUser 		: "ruTorrent cannot determine the UID of rTorrent user. Some functionality will be unavailable.",
 retryOnErrorTitle		: "If rTorrent is not available try again after",
 retryOnErrorList		: { 0: "Don't try again", 30: "30 sec", 60: "1 min", 120: "2 min", 300: "5 min", 900: "15 min" },
 statNotFound			: "rTorrent user can't access 'stat' program. Some functionality will be unavailable.",
 statNotFoundW			: "Webserver user can't access 'stat' program. Some functionality will be unavailable.",
 badrTorrentVersion		: "Plugin requires rTorrent version >=",
 badPHPVersion			: "Plugin requires PHP version >=",
 rTorrentExternalNotFoundError	: "Plugin will not work. rTorrent user can't access external program",
 rTorrentExternalNotFoundWarning: "Some functionality will be unavailable. rTorrent user can't access external program",
 webExternalNotFoundError	: "Plugin will not work. Webserver user can't access external program",
 webExternalNotFoundWarning	: "Some functionality will be unavailable. Webserver user can't access external program",
 rTorrentBadScriptPath		: "Plugin will not work. rTorrent user must have read/execute access to the file",
 rTorrentBadPHPScriptPath	: "Plugin will not work. rTorrent user must have read access to the file",
 dependenceError		: "Plugin will not work. It requires plugin(s)",
 peerAdd			: "Add Peer...",
 peerBan			: "Ban",
 peerKick			: "Kick",
 peerSnub			: "Snub",
 peerDetails			: "Details",
 peerUnsnub			: "Unsnub",
 peerAddLabel			: "Enter IP/Hostname[:port]",
 noTorrentList			: "Torrent list not yet available, connection to rTorrent not established.",
 yes				: "yes",
 no				: "no",
 DateFormat			: "Date format",
 DLStrategy			: "Download Strategy",
 prioritizeFirst		: "Leading Chunk First",
 prioritizeLast 		: "Trailing Chunk First",
 prioritizeNormal		: "Normal",
 updateTracker			: "Update Trackers",
 scrapeUpdate			: "Last Updated",
 trkInterval			: "Interval",
 logAutoSwitch			: "Autoswitch to 'Log' tab",
 showLabelSize			: "Show label size",
 phpParameterUnavailable	: "PHP directive register_argc_argv is set to OFF. Change to ON, otherwise some plugins won't work correctly.",
 addTorrentFailedURL		: "Failed to add torrent. Can't retrieve URL.",
 addTorrentFailedFile		: "Failed to add torrent. The retrieved content is not a valid torrent file.",
 addTorrentFailedDirectory	: "Failed to add torrent. Incorrect downloads directory was specified.",
 plgLaunch			: "Launch",
 plgLocked			: "Mandatory",
 phpExtensionNotFoundWarning	: "Some functionality will be unavailable. PHP extension must be installed",
 phpExtensionNotFoundError	: "Plugin will not work. PHP extension must be installed",
 trkPrivate			: "Private",
 dontSet			: "Don't set",
 webBadSessionError		: "Plugin will not work. Webserver user must have execute access to the rtorrent session directory",
 webBadSessionWarning		: "Some functionality will be unavailable. Webserver user must have execute access to the rtorrent session directory",
 Developers			: "Developers",
 Check_new_version		: "Check new version",
 here				: "here",
 Num_No 			: "No.", // This means "Number". To be used as header for number count, e.g.: throttle/ratio plugin
 This_screen			: "This screen",
 About_program			: "About ruTorrent",
 Toggle_menu			: "Toggle menu",
 Toggle_details 		: "Toggle details",
 Toggle_categories		: "Toggle categories",
 Delete_current_torrents	: "Delete current torrent(s)",
 Select_all			: "Select all",
 Deselect_all			: "Deselect all",
 showSpeedInTitle		: "Show speed in the title",
 badTempPath 			: "Webserver user doesn't have read/write/execute access to the tmp directory. ruTorrent will not work.",
 badTempPath2			: "rTorrent user must have read/execute access to the tmp directory. ruTorrent will not work.",
 doRandomizeHash		: "Randomize info hashes for cross-seeding",
 Recreate_files 		: "Queue files recreation",
 Address			: "Address",
 PeerDL 			: "Peer DL",
 PeerDownloaded 		: "Peer Downloaded",
 Save_path			: "Save path",
 registerMagnet			: "Try to register magnet protocol handler at start",
 linkTorTorrentRestored		: "Connection to rTorrent established.",
 removeAllTegs			: "Remove all tags"
};

==> rutorrent-4.3.6.tar.gz: ruTorrent-4.3.6/lang/zh-tw.js <==
﻿/*
 * Chinese Traditional language file.
 *
 * Author: Eyes Blue (kingofeyesblue@yahoo.com.tw)
 */

var theUILang =
{
 General			: "一般",
 Downloads			: "下載",
 Connection			: "連線",
 BitTorrent			: "任務",
 Format			: "Format",
 Advanced			: "進階",
 User_Interface			: "使用者界面",
 Confirm_del_torr		: "刪除 Torrent 時要求確認",
 Update_GUI_every		: "更新圖形介面頻率",
 ms				: "ms",
 Alt_list_bckgnd		: "交替顯示列表背景色",
 Show_cat_start			: "啟動時顯示類別",
 Show_det_start			: "啟動時顯示詳細內容",
 KeepSearches			: "Keep searches",
 KeepSelectedTab			: "Keep selected tab",
 KeepSelectedLabels		: "Keep selected labels",
 Dnt_start_down_auto		: "不要自動開始下載",
 Listening_Port			: "連接埠設定",
 Port_f_incom_conns		: "本機連接埠",
 Rnd_port_torr_start		: "rTorrent 啟動時使用隨機連接埠",
 Type				: "類型",
 Bandwidth_Limiting		: "頻寬限制",
 Global_max_upl			: "整體最大上傳速度",
 unlimited			: "無限制",
 Glob_max_downl			: "整體最大下載速度",
 Add_bittor_featrs		: "其他功能選項",
 En_DHT_ntw			: "啟用 DHT 網絡",
 Peer_exch			: "啟用使用者資訊交換",
 Ip_report_track		: "提供給 Tracker 的本機 IP 地址/主機名稱",
 Disabled			: "禁用",
 Enabled			: "啟用",
 ruTorrent_settings		: "設定",
 Doesnt_support			: "這個 ruTorrent 不支援您使用的瀏覽器",
 Name				: "名稱",
 Status				: "狀態",
 Size				: "大小",
 Done				: "完成率",
 Downloaded			: "已下載",
 Uploaded			: "已上傳",
 Ratio				: "分享率",
 DL				: "下載速度",
 UL				: "上傳速度",
 ETA				: "剩餘時間",
 Label				: "標籤",
 Peers				: "用戶數量",
 Seeds				: "種子數量",
 Remaining			: "剩餘時間",
 Priority			: "優先等級",
 Not_torrent_file		: "該檔案不是有效的 torrent 檔案",
 Pausing			: "暫停中",
 Seeding			: "做種中",
 Downloading			: "下載中",
 Checking			: "檢查中",
 Error				: "錯誤",
 Queued				: "排隊中",
 Finished			: "已完成",
 Stopped			: "已停止",
 Request_timed_out		: "連接 rTorrent 逾時",
 Start				: "開始",
 Pause				: "暫停",
 Stop				: "停止",
 Force_recheck			: "強制重新檢查",
 New_label			: "新建標籤...",
 Remove_label			: "移除標籤",
 Labels				: "標籤",
 Remove				: "移除",
 Delete_data			: "刪除下載的資料",
 Remove_and			: "移除並",
 Details			: "詳細內容...",
 Properties			: "屬性...",
 of				: "的", // this two creates line
 connected			: "已連接", // XX of YY connected
 High_priority			: "較高優先權",
 Normal_priority		: "正常優先權",
 Low_priority			: "較低優先權",
 Dont_download			: "不要下載",
 Files				: "文件",
 Logger				: "紀錄",
 s				: "s", // part of "KB/s"
 bytes				: "bytes",
 KB				: "KiB",
 MB				: "MiB",
 GB				: "GiB",
 TB				: "TiB",
 PB				: "PiB",
 Loading			: "載入中...",
 Torrent_file			: "Torrent 檔案",
 Torrent_URL			: "Torrent 網址",
 Torrent_properties		: "Torrent 屬性",
 Trackers			: "Tracker",
 Bandwidth_sett			: "頻寬設定",
 Number_ul_slots		: "上傳通道數",
 Peer_ex			: "用戶資料交換",
 Enter_label_prom		: "為選擇的 Torrent 輸入新的標籤",
 Remove_torrents		: "移除 Torrent(s)",
 Rem_torrents_prompt		: "您確定要移除選擇的 Torrent 嗎?",
 All				: "全部",
 Active				: "活動",
 Inactive			: "停止",
 No_label			: "其他",
 Transfer			: "傳輸",
 Time_el			: "已用時間",
 Share_ratio			: "分享比率",
 Down_speed			: "下載速度",
 Ul_speed			: "上傳速度",
 Wasted				: "丟棄數據",
 Tracker			: "Tracker",
 Track_URL			: "Tracker 連接",
 Track_status			: "Tracker 狀態",
 Created_on			: "建立時間",
 Save_as			: "檔案儲存位置",
 Comment			: "附註說明",
 add_button			: "開啟",
 add_url			: "下載",
 ok				: "確定",
 Cancel				: "取消",
 mnu_add			: "開啟 Torrent",
 mnu_remove			: "移除",
 mnu_start			: "開始",
 mnu_pause			: "暫停",
 mnu_stop			: "停止",
 mnu_rss			: "RSS 下載器",
 mnu_settings			: "設定",
 mnu_search			: "搜尋",
 mnu_lang			: "語言",
 torrent_add			: "開啟 Torrent", /*Caption of torrent add box*/
 time_w				: "週 ", /*for x weeks*/
 time_d				: "日 ", /*for x days remaining*/
 time_h				: "時 ", /*for x hours remaining*/
 time_m				: "分 ", /*for x minutes remaining*/
 time_s				: "秒 ", /*for x seconds remaining*/
 Base_directory			: "存放目錄",
 Number_Peers_min		: "與其他使用者連線的最小數量",
 Number_Peers_max		: "與其他使用者連線的最大數量",
 Tracker_Numwant		: "向tracker查詢使用者資訊時，期望一次回應的數量",
 Number_Peers_For_Seeds_min	: "作種時與其他使用者連線的最小數量",
 Number_Peers_For_Seeds_max	: "作種時與其他使用者連線的最大數量",
 Enable_port_open		: "監聽連接埠",
 dht_port			: "DHT 使用的 UDP 連接埠",
 Other_Limiting			: "其他限制",
 Number_dl_slots		: "最大下載連線數量",
 Glob_max_memory		: "整體最大記憶體可用量",
 Glob_max_files			: "整體最大可開啟的檔案數量",
 Glob_max_http			: "整體最大 HTTP 連線數量",
 Open_label         : "打開",
 Other_sett			: "其他設定",
 Directory_For_Dl		: "預設下載目錄",
 Check_hash			: "下載完成後使用 Hash 完整驗證所有檔案",
 Hash				: "Hash",
 DisableTracker			: "停用",
 EnableTracker			: "啟用",
 ClientVersion			: "Client",
 Flags				: "Flags",
 ReqTimeout			: "判定逾時",
 GetTrackerMessage		: "從tracker接收使用者資訊",
 Help				: "Help",
 Speed				: "速度",
 Dont_add_tname			: "請勿將 torrent 名稱作為目錄名稱",
 Free_Disk_Space		: "磁碟可用空間",
 badXMLRPCVersion		: "rTorrent使用了錯誤的xmlrpc-c版本編譯, 該版本不含i8支援,版本必須大於或等於1.11版,某些功能將無法使用",
 badLinkTorTorrent		: "錯誤的rTorrent連結, 請檢查rTorrent是否已經正確執行, 請確認rTorrent設定檔與config.php中的 $scgi_port 與 $scgi_host 相符合",
 badUploadsPath			: "網頁伺服器無法存取(讀/寫/執行) torrent 的存放目錄，您無法從 ruTorrent 新增 torrent",
 badSettingsPath		: "網頁伺服器無法存取(讀/寫/執行)設定檔存放目錄，ruTorrent 無法儲存設定",
 mnu_help			: "關於",
 badUploadsPath2		: "rTorrent's 所設定的使用者無法讀/執行 torrent 的存放目錄，您無法從 ruTorrent 新增 torrent",
 View				: "檢視",
 AsList				: "列表檢視",
 AsTree				: "樹狀檢視",
 Group				: "群組",
 SuperSeed			: "超級種子",
 badTestPath			: "rTorrent's 所設定的使用者無權限讀/執行./test.sh，ruTorrent 無法正常運作",
 badSettingsPath2		: "rTorrent's 無法存取(讀/寫/執行)您所設定的使用者家目錄，ruTorrent 無法正常運作",
 scrapeDownloaded		: "已下載",
 Total				: "總計",
 PCRENotFound			: "PHP 中未安裝 PCRE 模組，ruTorrent 無法正常運>作",
 addTorrentSuccess		: "torrent 檔案上傳完成",
 addTorrentFailed		: "錯誤: torrent 檔案無法傳送到 rTorrent",
 pnlViews			: "Views",
 NewView			: "New View",
 MoveView			: {base: "Move view", top: "To top", up: "Up", down: "Down", bottom: "To bottom"},
 RenameView			: "Rename view",
 RemoveActiveViews		: "Remove active views",
 SaveCurrentView		: "Save current view",
 showViewPanel			: "Show Views panel",
 showViewLabelSize		: "Show label size in Views panel",
 pnlState			: "狀態",
 newLabel			: "新標籤",
 enterLabel			: "Enter Label",
 UIEffects			: "Show effects for UI elements",
 Plugins			: "Plugins",
 plgName			: "Name",
 plgStatus			: "Status",
 plgLoaded			: "Loaded",
 plgDisabled			: "Not loaded",
 plgVersion			: "Version",
 plgAuthor			: "Author",
 plgDescr			: "Description",
 mnu_go				: "Go",
 pluginCantStart		: "Plugin failed to start.",
 doFastResume			: "Fast resume",
 innerSearch			: "Local Torrents",
 removeTeg			: "Remove tag",
 errMustBeInSomeHost		: "ruTorrent and rTorrent must be installed on the same host. Plugin will not work.",
 warnMustBeInSomeHost		: "ruTorrent and rTorrent must be installed on the same host. Some functionality will be unavailable.",
 plgShutdown			: "Unload",
 limit				: "Limit",
 speedList			: "Speed Popup List (comma-separated)",
 DecimalPlacesSizes		: "Decimal Places of Sizes",
 CatListSizeDecimalPlaces	: "In category list",
 TableSizeDecimalPlaces	: "In tables",
 DetailsSizeDecimalPlaces	: "In general tab",
 OtherSizeDecimalPlaces	: "Other",
 Default	: "Default",
 ClearButton			: "Clear",
 dontShowTimeouts		: "Ignore message about timeouts",
 fullTableRender		: "Full render of large tables",
 showScrollTables		: "Show table contents while scrolling",
 idNotFound			: "rTorrent user can't access 'id' program. Some functionality will be unavailable.",
 gzipNotFound			: "Webserver user can't access 'gzip' program. ruTorrent will not work.",
 cantObtainUser			: "ruTorrent cannot determine the UID of rTorrent user. Some functionality will be unavailable.",
 retryOnErrorTitle		: "If rTorrent is not available try again after",
 retryOnErrorList		: { 0: "Don't try again", 30: "30 sec", 60: "1 min", 120: "2 min", 300: "5 min", 900: "15 min" },
 statNotFound			: "rTorrent user can't access 'stat' program. Some functionality will be unavailable.",
 statNotFoundW			: "Webserver user can't access 'stat' program. Some functionality will be unavailable.",
 badrTorrentVersion		: "Plugin requires rTorrent version >=",
 badPHPVersion			: "Plugin requires PHP version >=",
 rTorrentExternalNotFoundError	: "Plugin will not work. rTorrent user can't access external program",
 rTorrentExternalNotFoundWarning: "Some functionality will be unavailable. rTorrent user can't access external program",
 webExternalNotFoundError	: "Plugin will not work. Webserver user can't access external program",
 webExternalNotFoundWarning	: "Some functionality will be unavailable. Webserver user can't access external program",
 rTorrentBadScriptPath		: "Plugin will not work. rTorrent user must have read/execute access to the file",
 rTorrentBadPHPScriptPath	: "Plugin will not work. rTorrent user must have read access to the file",
 dependenceError		: "Plugin will not work. It requires plugin(s)",
 peerAdd			: "Add Peer...",
 peerBan			: "Ban",
 peerKick			: "Kick",
 peerSnub			: "Snub",
 peerDetails			: "Details",
 peerUnsnub			: "Unsnub",
 peerAddLabel			: "Enter IP/Hostname[:port]",
 noTorrentList			: "Torrent list not yet available, connection to rTorrent not established.",
 yes				: "yes",
 no				: "no",
 DateFormat			: "Date format",
 DLStrategy			: "Download Strategy",
 prioritizeFirst		: "Leading Chunk First",
 prioritizeLast			: "Trailing Chunk First",
 prioritizeNormal		: "Normal",
 updateTracker			: "Update Trackers",
 scrapeUpdate			: "Last Updated",
 trkInterval			: "Interval",
 logAutoSwitch			: "Autoswitch to 'Log' tab",
 showStateLabelSize		: "Show label size in State panel",
 showLabelSize			: "Show label size in Labels panel",
 showSearchLabelSize		: "Show label size in Search panel",
 showCustomLabelTree		: "Show label path tree",
 labelSizeRightAlign		: "Right align size in category list",
 showEmptyPathLabel		: "Show empty path labels",
 showLabelTextOverflow	: "Allow overflow of label text",
 showOpenStatus		: "Show open status in status bar",
 requiresAtLeastRtorrent		: "Requires rTorrent >= {version}", // ... v0.9.7
 phpParameterUnavailable	: "PHP directive register_argc_argv is set to OFF. Change to ON, otherwise some plugins won't work correctly.",
 addTorrentFailedURL		: "Failed to add torrent. Can't retrieve URL.",
 addTorrentFailedFile		: "Failed to add torrent. The retrieved content is not a valid torrent file.",
 addTorrentFailedDirectory	: "Failed to add torrent. Incorrect downloads directory was specified.",
 plgLaunch			: "Launch",
 plgLocked			: "Mandatory",
 phpExtensionNotFoundWarning	: "Some functionality will be unavailable. PHP extension must be installed",
 phpExtensionNotFoundError	: "Plugin will not work. PHP extension must be installed",
 trkPrivate			: "Private",
 dontSet			: "Don't set",
 webBadSessionError		: "Plugin will not work. Webserver user must have execute access to the rtorrent session directory",
 webBadSessionWarning		: "Some functionality will be unavailable. Webserver user must have execute access to the rtorrent session directory",
 Developers			: "Developers",
 Check_new_version		: "Check new version",
 here				: "here",
 Num_No				: "No.", // This means "Number". To be used as header for number count, e.g.: throttle/ratio plugin
 This_screen			: "This screen",
 About_program			: "About ruTorrent",
 Toggle_menu			: "Toggle menu",
 Toggle_details			: "Toggle details",
 Toggle_categories		: "Toggle categories",
 Delete_current_torrents	: "Delete current torrent(s)",
 Select_all			: "Select all",
 Deselect_all			: "Deselect all",
 showSpeedInTitle		: "Show speed in the title",
 speedGraphDuration		: "Duration of speed graph",
 speedGraphDurationOptions		: {600: "10 min", 1800: "30 min", 3600: "1 hr", 10800: "3 hrs"},
 badTempPath			: "Webserver user doesn't have read/write/execute access to the tmp directory. ruTorrent will not work.",
 badTempPath2			: "rTorrent user must have read/execute access to the tmp directory. ruTorrent will not work.",
 doRandomizeHash		: "Randomize info hashes for cross-seeding",
 Recreate_files			: "Queue Files Recreation",
 Address			: "Address",
 PeerDL				: "Peer DL",
 PeerDownloaded			: "Peer Downloaded",
 Save_path			: "Save path",
 registerMagnet			: "Try to register magnet protocol handler at start",
 linkTorTorrentRestored		: "Connection to rTorrent established.",
 removeAllTegs			: "Remove all tags",
 Torrents			: "Torrent(s)",
 copyToClipboardFailed		: "The copy function isn't working in your browser.\nPlease copy this content manually:\n\n",
 copyToClipboardSuccess		: "Copied to clipboard successfully!"
};
